---
title: '송금대행 일괄지급은 어떻게 이용할 수 있나요? '
category: 자주 묻는 질문 (일반 문의) > 파트너정산자동화 > 파트너정산자동화
seo:
  title: '송금대행 일괄지급은 어떻게 할 수 있나요? '
  keywords:
    - 정산금계산, 메타데이터, 정산파라미터, 정산금자동계산, 정산시스템
tags:
  - "\b송금대행일괄지급"
  - 지급대행
pgCompanies:
  - 공통
searchTags:
  - 송금
  - 대량이체
  - 지급대행
  - 송금대행
  - 파트너정산자동화
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="" title="포트원 송금대행 일괄지급 서비스에 대한 기본 가이드입니다." />

### **송금대행 일괄지급이란?**

- 한 번의 버튼 클릭으로 계산된 정산금을 여러 파트너에게 대량으로 이체할 수 있는 서비스입니다.
- 지급 결과는 실시간으로 조회 가능하며, 성공/실패 금액 및 실패 사유 또한 확인할 수 있습니다.
- 즉시 지급과 예약 지급을 지원합니다.

### **PG사 지급대행 서비스와 어떤 차이가 있나요?**

- PG사 지급대행 서비스와 파트너 정산 서비스는 모두 전자금융거래법을 준수하는 합법적인 정산을 진행한다는 점에서는 동일하지만 다음과 같은 차이점이 존재합니다.
- 첫째, 정산 프로세스 통합 수준이 다릅니다. 지급대행 서비스는 PG사가 판매대금 지급만을 대행하지만, 파트너 정산 서비스는 정산금 계산, 지급, 세금계산서 발행 등 전체 정산 프로세스를 통합 관리합니다.
- 둘째, 운영 공수를 줄일 수 있는 세부 기능에서 큰 차이가 있습니다.파트너 정산 서비스는 즉시 지급, 개인 판매자 정산, 해외 송금 대행 등의 편의 기능을 포함하고 있습니다.
- 마지막으로, 파트너 정산 서비스는 복수 PG사/간편결제사의 정산 데이터를 통합 관리할 수 있습니다.
- 이처럼 파트너 정산 서비스는 정산 프로세스 통합, 기능 다양성, 데이터 통합 측면에서 지급대행 서비스보다 고도화된 맞춤형 솔루션이라고 할 수 있습니다.
- 더 많은 정보가 필요하시다면? 아래 콘텐츠를 확인해보세요!
  - [PG사 지급대행 서비스와 파트너 정산 자동화 서비스 전격 비교 ](<> "https://blog.portone.io/ps_vs-transfer-delegation/")

### **실시간 지급이 가능한가요?**

- 네, 포트원 송금대행 일괄지급 서비스는 실시간 지급 기능을 지원합니다.
- \[즉시 지급] 옵션을 선택하여 이체 실행 시, 전자서명을 완료하는 즉시 실시간으로 이체가 시작됩니다.
- 공휴일 없이 은행 점검 시간을 제외하고 24시간 7일 내내 송금대행 일괄지급 서비스를 이용할 수 있습니다.

### **예약 지급이 가능한가요?**

- 네, 포트원 송금대행 일괄지급 서비스는 예약 지급 기능을 지원합니다.
- 총 10건을 예약할 수 있고, 예약 시간 변경과 예약 취소도 가능합니다.

### **통장 메모를 기입할 수 있나요?**

- 네, 받는 사람 통장 메모, 보내는 사람 통장 메모를 기입할 수 있습니다.
- 송금 건마다 통장 메모를 다르게 기입할 수 있고, 모든 송금 건에 대한 통장 메모를 일괄 입력할 수도 있습니다.
- 기본 통장 메모를 저장하면 송금할 때마다 번거롭게 새로 통장메모를 기입할 필요 없이 이용 가능합니다.

### **안전하고 합법적인 것 맞나요?**

<Callout content="포트원 서비스는 안전하고 합법적인 송금대행 서비스를 지원합니다. 
" />

- 첫째, 파트너정산 자동화 서비스는 전자금융거래법에도 안전한 지급대행 / 송금대행 서비스 구조를 지원합니다.
- 둘째, 안전한 송금대행 일괄지급 실행을 위해 \[관리자] 권한을 가진 사람만 송금대행을 실행할 수 있습니다.
- 셋째, 최종적으로 지급 지시에 대한 권한을 가진 사람만 실제 송금을 실행할 수 있도록 송금의 마지막 단계에서 \[공동인증서 전자서명]을 확인받고 있습니다.
- 더 많은 정보가 필요하시다면? 아래 콘텐츠를 확인해보세요!
  - [전자금융거래법 공청회 직접 다녀와서 알려드립니다](https://blog.portone.io/ps_public-hearing/)
  - [플랫폼사라면 꼭 해야하는 정산, 전금법 개정으로 고민이 있다면 ‘이것만’ 확인하세요.](https://blog.portone.io/partner-settlement-lawinfo/ "‘플랫폼사’라면 꼭 해야하는 정산, 전금법 개정으로 고민이 있다면 ‘이것만’ 확인하세요.")

### **서비스 이용에 관심 있으시다면?**

문의를 남겨주시면 담당팀이 영업일 2일 내로 연락 드리겠습니다.

<Callout content="" title="도입문의 바로가기 ↗" />

###
